;; Generated package description from vertico.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "vertico" "2.8.0.20260517.213709" "VERTical Interactive COmpletion" '((emacs "29.1") (compat "31")) :commit "73b3e71283254efd9d63c934f041397c2e4f0474" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("convenience" "files" "matching" "completion") :url "https://github.com/minad/vertico")
